KeyboardKeyTheme class final
Theme configuration for regular keyboard keys.
- Implementers
Constructors
-
KeyboardKeyTheme({required Color backgroundColor, required Color pressedBackgroundColor, required Color foregroundColor, Color? disabledBackgroundColor, Color? disabledForegroundColor, List<
BoxShadow> ? shadows, List<BoxShadow> ? innerShadows, Color? overlayBackgroundColor, Color? overlayTextColor, TextStyle? keyTextStyle}) -
const
Properties
- backgroundColor → Color
-
The color of the keys.
final
- disabledBackgroundColor → Color?
-
The background color of the keys when they are disabled.
If null, defaults to backgroundColor with 40% opacity.
final
- disabledForegroundColor → Color?
-
The color of the text/icon when the key is disabled.
If null, defaults to foregroundColor with 40% opacity.
final
- foregroundColor → Color
-
The color of the text/icon.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
innerShadows
→ List<
BoxShadow> ? -
The inner shadows of the keys.
final
- keyTextStyle → TextStyle?
-
The text style for key labels.
final
- overlayBackgroundColor → Color?
-
The background color of the key press overlay popup.
final
- overlayTextColor → Color?
-
The text color of the key press overlay popup.
final
- pressedBackgroundColor → Color
-
The color of the keys when they are pressed.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shadows
→ List<
BoxShadow> ? -
The shadows of the keys.
final
Methods
-
copyWith(
{Color? backgroundColor, Color? pressedBackgroundColor, Color? foregroundColor, Color? disabledBackgroundColor, Color? disabledForegroundColor, List< BoxShadow> ? shadows, List<BoxShadow> ? innerShadows, Color? overlayBackgroundColor, Color? overlayTextColor, TextStyle? keyTextStyle}) → KeyboardKeyTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited